@@ -696,7 +696,7 @@ ST_FUNC Tcl_Channel tcc_open(TCCState *s1, const char *filename)
     } else {
         path = Tcl_NewStringObj(filename,-1);
         Tcl_IncrRefCount(path);
-        fd = Tcl_FSOpenFileChannel(NULL,path, "r", 0);
+        fd = Tcl_FSOpenFileChannel(NULL,path, "RDONLY BINARY", 0);
         Tcl_DecrRefCount(path);
     }
 
